import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.assertions._jsii
import aws_cdk.aws_events._jsii
import aws_cdk.aws_events_targets._jsii
import aws_cdk.aws_lambda._jsii
import aws_cdk.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "cdk-ecr-image-scan-notify",
    "0.0.216",
    __name__[0:-6],
    "cdk-ecr-image-scan-notify@0.0.216.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
